.. tutorials


Tutorials
=========

.. toctree::
    :maxdepth: 1
    :caption: Spatial 2SLS

    notebooks/GM_Lag_example.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Spatial Panel Models with Fixed Effects
    
    notebooks/Panel_FE_example.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Skater_reg: Endogenous Spatial Regimes
    
    notebooks/skater_reg.ipynb
